@@ -123,6 +123,7 @@ connect( ui.pushButtonMakeindex, SIGNAL(clicked()), this, SLOT(browseMakeindex()
 connect( ui.pushButtonDviviewer, SIGNAL(clicked()), this, SLOT(browseDviviewer()));
 connect( ui.pushButtonPsviewer, SIGNAL(clicked()), this, SLOT(browsePsviewer()));
 connect( ui.pushButtonPdflatex, SIGNAL(clicked()), this, SLOT(browsePdflatex()));
+connect( ui.pushButtonXelatex, SIGNAL(clicked()), this, SLOT(browseXelatex()));
 connect( ui.pushButtonDvipdfm, SIGNAL(clicked()), this, SLOT(browseDvipdfm()));
 connect( ui.pushButtonPs2pdf, SIGNAL(clicked()), this, SLOT(browsePs2pdf()));
 connect( ui.pushButtonPdfviewer, SIGNAL(clicked()), this, SLOT(browsePdfviewer()));
@@ -369,7 +370,8 @@ QString location=QFileDialog::getOpenFileName(this,tr("Browse program"),QDir::ro
 if ( !location.isEmpty() ) 
 	{
 	location.replace(QString("\\"),QString("/"));
-	location="\""+location+"\" %.aux";
+	if (location.contains("bibtex") && !location.contains("MiKTeX")) location="\""+location+"\" %.aux";
+	else location="\""+location+"\" %";
 	ui.lineEditBibtex->setText( location );
 	}
 }
@@ -418,6 +420,17 @@ if ( !location.isEmpty() )
 	}
 }
 
+void ConfigDialog::browseXelatex()
+{
+QString location=QFileDialog::getOpenFileName(this,tr("Browse program"),QDir::rootPath(),"Program (*)",0,QFileDialog::DontResolveSymlinks);
+if ( !location.isEmpty() ) 
+	{
+	location.replace(QString("\\"),QString("/"));
+	location="\""+location+"\" -interaction=nonstopmode %.tex";
+	ui.lineEditXelatex->setText( location );
+	}
+}
+
 void ConfigDialog::browseDvipdfm()
 {
 QString location=QFileDialog::getOpenFileName(this,tr("Browse program"),QDir::rootPath(),"Program (*)",0,QFileDialog::DontResolveSymlinks);
@@ -595,6 +608,9 @@ usualCommands.append(ui.lineEditLatexmk->text());
 usualNames.append(tr("R Sweave"));
 usualCommands.append(ui.lineEditSweave->text());
 
+usualNames.append(tr("XeLaTeX"));
+usualCommands.append(ui.lineEditXelatex->text());
+
 userquickdlg= new UserQuickDialog(this,usualNames,usualCommands);
 if ( userquickdlg->exec() )
    {
