@@ -67,7 +67,7 @@ LatexEditor(QWidget *parent,QFont & efont, QList<QColor> edcolors, QList<QColor>
 static void clearMarkerFormat(const QTextBlock &block, int markerId);
 void gotoLine( int line );
 bool search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor, bool isRegExp );
-void replace( const QString &r);
+void replace( const QString &r,bool isRegExp,const QString &o);
 void commentSelection();
 void uncommentSelection();
 void indentSelection();
