@@ -1,7 +1,7 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2011 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2012 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
- *   addons by Luis Silvestre ; Tom Hoffmann                               *
+ *   addons by Luis Silvestre                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -80,6 +80,7 @@ public slots:
 void load( const QString &f );
 void setLine( const QString &line );
 void ToggleMode();
+void insertFromCommandLine(const QString &entity);
 void onOtherInstanceMessage(const QString &);  // For messages for the single instance
 
 private:
@@ -97,6 +98,8 @@ bool copyFile(QString origin,QString destination);
 void createBuildSubdirectory(QString fn);
 QString outputName(QString finame,QString extension);
 QString outputBaseName(QString finame);
+bool gtkSession();
+void setMasterDocument(const QString &fn);
 
 int untitled_id;
 
@@ -160,7 +163,7 @@ int split1_right, split1_left, split2_top, split2_bottom, quickmode, tabwidth;
 bool singlemode, wordwrap, parenmatch, showline, showoutputview, showstructview, showpdfview, showsourceview, showfilesview, ams_packages, makeidx_package, completion, inlinespellcheck, modern_style, new_gui, builtinpdfview, singleviewerinstance, babel_package, geometry_package, graphicx_package, watchfiles, autosave, tabspaces, useoutputdir ;
 bool lmodern_package, kpfonts_package, fourier_package;
 QString document_class, typeface_size, paper_size, document_encoding, author, geometry_options, babel_default;
-QString latex_command, viewdvi_command, dvips_command, dvipdf_command, metapost_command, psize;
+QString latex_command, viewdvi_command, dvips_command, dvipdf_command, metapost_command, psize, xelatex_command, htlatex_command, htlatex_options;
 QString viewps_command, ps2pdf_command, makeindex_command, bibtex_command, pdflatex_command, viewpdf_command, userquick_command, ghostscript_command, asymptote_command, latexmk_command, sweave_command, texdoc_command;
 QString spell_dic, spell_ignored_words;
 QString lastDocument, input_encoding, lastChild, lastTemplate;
@@ -170,6 +173,7 @@ QStringList labelitem, bibitem, listbibfiles, listchildfiles;
 Userlist UserMenuName, UserMenuTag;
 UserCd UserToolName, UserToolCommand;
 QString keyToggleFocus;
+QString extra_path;
 qreal lastScale;
 //dialogs
 QPointer<ScanDialog> scanDialog;
@@ -391,6 +395,7 @@ void MetaPost();
 void Asymptote();
 void LatexMk();
 void Sweave();
+void Xelatex();
 void AsyFile(QString asyfile);
 void UserTool1();
 void UserTool2();
@@ -402,6 +407,7 @@ void doCompile();
 void doView();
 void jumpToPdfline(int line);
 void OpenTerminal();
+void Export();
 
 void LoadLog();
 void ViewLog();
